import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/strategies/analytics_data_loading_strategy.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/fetch_energy_management_data_helper.dart';
import 'package:syncrow_web/pages/space_tree/bloc/space_tree_bloc.dart';
import 'package:syncrow_web/pages/space_tree/bloc/space_tree_event.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/community_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/space_model.dart';

class EnergyManagementDataLoadingStrategy implements AnalyticsDataLoadingStrategy {
  @override
  void onCommunitySelected(
    BuildContext context,
    CommunityModel community,
    List<SpaceModel> spaces,
  ) {
    context.read<SpaceTreeBloc>().add(
          OnCommunitySelected(
            community.uuid,
            spaces,
          ),
        );
    FetchEnergyManagementDataHelper.loadEnergyManagementData(context);
  }

  @override
  void onSpaceSelected(
    BuildContext context,
    CommunityModel community,
    SpaceModel space,
  ) {
    context.read<SpaceTreeBloc>().add(
          OnSpaceSelected(
            community,
            space.uuid ?? '',
            space.children,
          ),
        );
    FetchEnergyManagementDataHelper.loadEnergyManagementData(context);
  }

  @override
  void onChildSpaceSelected(
    BuildContext context,
    CommunityModel community,
    SpaceModel child,
  ) {
    context.read<SpaceTreeBloc>().add(
          OnSpaceSelected(
            community,
            child.uuid ?? '',
            child.children,
          ),
        );
    FetchEnergyManagementDataHelper.loadEnergyManagementData(context);
  }

  @override
  void clearData(BuildContext context) {
    context.read<SpaceTreeBloc>().add(const SpaceTreeClearSelectionEvent());
    FetchEnergyManagementDataHelper.clearAllData(context);
  }
}
