import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/analytics/models/energy_data_model.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/energy_management_charts_helper.dart';
import 'package:syncrow_web/utils/color_manager.dart';

// energy_consumption_chart will return id, name and consumption
const phasesJson = {
  "1": {
    "phaseOne": 1000,
    "phaseTwo": 2000,
    "phaseThree": 3000,
  }
};

class TotalEnergyConsumptionChart extends StatelessWidget {
  const TotalEnergyConsumptionChart({required this.chartData, super.key});

  final List<EnergyDataModel> chartData;

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: LineChart(
        LineChartData(
          titlesData: EnergyManagementChartsHelper.titlesData(context),
          gridData: EnergyManagementChartsHelper.gridData(),
          borderData: EnergyManagementChartsHelper.borderData(),
          lineTouchData: EnergyManagementChartsHelper.lineTouchData(),
          lineBarsData: _lineBarsData,
        ),
        duration: Durations.extralong1,
        curve: Curves.easeIn,
      ),
    );
  }

  List<LineChartBarData> get _lineBarsData {
    return [
      LineChartBarData(
        preventCurveOvershootingThreshold: 0.1,
        curveSmoothness: 0.55,
        preventCurveOverShooting: true,
        spots: chartData
            .asMap()
            .entries
            .map(
              (entry) => FlSpot(
                entry.key.toDouble(),
                entry.value.value,
              ),
            )
            .toList(),
        color: ColorsManager.blueColor.withValues(alpha: 0.6),
        shadow: const Shadow(color: Colors.black12),
        show: true,
        isCurved: true,
        belowBarData: BarAreaData(
          show: true,
          gradient: LinearGradient(
            colors: [
              ColorsManager.vividBlue.withValues(alpha: 0.3),
              ColorsManager.vividBlue.withValues(alpha: 0.2),
              ColorsManager.vividBlue.withValues(alpha: 0.1),
              Colors.transparent,
            ],
            begin: Alignment.center,
            end: Alignment.bottomCenter,
          ),
        ),
        dotData: const FlDotData(show: false),
        isStrokeCapRound: true,
        barWidth: 3,
      ),
    ];
  }
}
