import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_date_picker_bloc/analytics_date_picker_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/realtime_device_changes/realtime_device_changes_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/fetch_energy_management_data_helper.dart';
import 'package:syncrow_web/pages/analytics/modules/occupancy/blocs/occupancy/occupancy_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/occupancy/blocs/occupancy_heat_map/occupancy_heat_map_bloc.dart';
import 'package:syncrow_web/pages/analytics/params/get_occupancy_heat_map_param.dart';
import 'package:syncrow_web/pages/analytics/params/get_occupancy_param.dart';

abstract final class FetchOccupancyDataHelper {
  const FetchOccupancyDataHelper._();

  static void loadOccupancyData(BuildContext context) {
    final (selectedCommunities, selectedSpaces) =
        FetchEnergyManagementDataHelper.getSelectedCommunitiesAndSpaces(context);
    if (selectedCommunities.isEmpty && selectedSpaces.isEmpty) {
      context.read<OccupancyBloc>().add(
            const ClearOccupancyEvent(),
          );
      context.read<OccupancyHeatMapBloc>().add(
            const ClearOccupancyHeatMapEvent(),
          );
      return;
    }

    final datePickerState = context.read<AnalyticsDatePickerBloc>().state;

    context.read<OccupancyBloc>().add(
          LoadOccupancyEvent(
            GetOccupancyParam(
              monthDate:
                  '${datePickerState.monthlyDate.year}-${datePickerState.monthlyDate.month}',
              spaceUuid: selectedSpaces.firstOrNull,
              communityUuid: selectedCommunities.first,
            ),
          ),
        );

    context.read<OccupancyHeatMapBloc>().add(
          LoadOccupancyHeatMapEvent(
            GetOccupancyHeatMapParam(
              spaceId: selectedSpaces.isNotEmpty ? selectedSpaces.first : '',
              communityId:
                  selectedCommunities.isNotEmpty ? selectedCommunities.first : '',
              year: datePickerState.yearlyDate,
            ),
          ),
        );

    context.read<RealtimeDeviceChangesBloc>()
      ..add(const RealtimeDeviceChangesClosed())
      ..add(
        const RealtimeDeviceChangesStarted('14fe6e7e-47af-4a07-ae0a-7c4a26ef8135'),
      );
  }
}
