import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class OccupancyPaintItem {
  final int index;
  final int value;

  const OccupancyPaintItem({required this.index, required this.value});
}

class OccupancyPainter extends CustomPainter {
  OccupancyPainter({
    required this.items,
    required this.maxValue,
  });

  final List<OccupancyPaintItem> items;
  final int maxValue;

  static const double cellSize = 16.0;

  @override
  void paint(Canvas canvas, Size size) {
    final Paint fillPaint = Paint();
    final Paint borderPaint = Paint()
      ..color = ColorsManager.grayBorder.withValues(alpha: 0.4)
      ..style = PaintingStyle.stroke;

    for (final item in items) {
      final column = item.index ~/ 7;
      final row = item.index % 7;

      final x = column * cellSize;
      final y = row * cellSize;

      fillPaint.color = _getColor(item.value);
      final rect = Rect.fromLTWH(x, y, cellSize, cellSize);
      canvas.drawRect(rect, fillPaint);

      _drawDashedLine(
        canvas,
        Offset(x, y),
        Offset(x + cellSize, y),
        borderPaint,
      );
      _drawDashedLine(
        canvas,
        Offset(x, y + cellSize),
        Offset(x + cellSize, y + cellSize),
        borderPaint,
      );

      canvas.drawLine(Offset(x, y), Offset(x, y + cellSize), borderPaint);
      canvas.drawLine(
          Offset(x + cellSize, y), Offset(x + cellSize, y + cellSize), borderPaint);
    }
  }

  void _drawDashedLine(Canvas canvas, Offset start, Offset end, Paint paint) {
    const double dashWidth = 2.0;
    const double dashSpace = 4.0;
    final double totalLength = (end - start).distance;
    final Offset direction = (end - start) / (end - start).distance;

    double currentLength = 0.0;
    while (currentLength < totalLength) {
      final Offset dashStart = start + direction * currentLength;
      final double nextLength = currentLength + dashWidth;
      final Offset dashEnd =
          start + direction * (nextLength < totalLength ? nextLength : totalLength);
      canvas.drawLine(dashStart, dashEnd, paint);
      currentLength = nextLength + dashSpace;
    }
  }

  Color _getColor(int value) {
    if (maxValue == 0) return ColorsManager.vividBlue.withValues(alpha: 0);
    final opacity = value.clamp(0, maxValue) / maxValue;
    return ColorsManager.vividBlue.withValues(alpha: opacity);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) => false;
}
