import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/device_managment/device_setting/bloc/device_info_model.dart';
import 'package:syncrow_web/pages/device_managment/device_setting/bloc/setting_bloc_state.dart';
import 'package:syncrow_web/pages/device_managment/device_setting/bloc/sub_space_model.dart';
import 'package:syncrow_web/services/devices_mang_api.dart';
import 'package:syncrow_web/utils/snack_bar.dart';
part 'setting_bloc_event.dart';

class SettingBlocBloc extends Bloc<SettingBlocEvent, DeviceSettingsState> {
  final String deviceId;
  SettingBlocBloc({
    required this.deviceId,
  }) : super(const SettingBlocInitial()) {
    on<DeviceSettingInitialInfo>(fetchDeviceInfo);
    on<SaveNameEvent>(saveName);
    on<ChangeNameEvent>(_changeName);
    on<DeleteDeviceEvent>(deleteDevice);
    //on<FetchRoomsEvent>(_fetchRoomsAndDevices);
  }
  static String deviceName = '';
  final TextEditingController nameController =
      TextEditingController(text: deviceName);
  List<SubSpaceModel> roomsList = [];
  bool isEditingName = false;

  bool _validateInputs() {
    final nameError = fullNameValidator(nameController.text);
    if (nameError != null) {
      CustomSnackBar.displaySnackBar(nameError);
      return true;
    }
    return false;
  }

  String? fullNameValidator(String? value) {
    if (value == null) return 'name is required';
    final withoutExtraSpaces = value.replaceAll(RegExp(r"\s+"), ' ').trim();
    if (withoutExtraSpaces.length < 2 || withoutExtraSpaces.length > 30) {
      return 'name must be between 2 and 30 characters long';
    }
    if (RegExp(r"/[^ a-zA-Z0-9-\']/").hasMatch(withoutExtraSpaces)) {
      return 'Only alphanumeric characters, space, dash and single quote are allowed';
    }
    return null;
  }

  Future<void> saveName(
      SaveNameEvent event, Emitter<DeviceSettingsState> emit) async {
    if (_validateInputs()) return;
    try {
      emit(SettingLoadingState());
      var response = await DevicesManagementApi.putDeviceName(
          deviceId: deviceId, deviceName: nameController.text);
      add(DeviceSettingInitialInfo());
      CustomSnackBar.displaySnackBar('Save Successfully');
      emit(UpdateSettingState(deviceName: nameController.text));
    } catch (e) {
      emit(ErrorState(message: e.toString()));
    } finally {
      // isSaving = false;
    }
  }

  DeviceInfoModel deviceInfo = DeviceInfoModel(
    activeTime: 0,
    category: "",
    categoryName: "",
    createTime: 0,
    gatewayId: "",
    icon: "",
    ip: "",
    lat: "",
    localKey: "",
    lon: "",
    model: "",
    name: "",
    nodeId: "",
    online: false,
    ownerId: "",
    productName: "",
    sub: false,
    timeZone: "",
    updateTime: 0,
    uuid: "",
    productUuid: "",
    productType: "",
    permissionType: "",
    macAddress: "",
    subspace: Subspace(
      uuid: "",
      createdAt: "",
      updatedAt: "",
      subspaceName: "",
    ),
  );

  Future fetchDeviceInfo(
      DeviceSettingInitialInfo event, Emitter<DeviceSettingsState> emit) async {
    try {
      emit(SettingLoadingState());
      var response = await DevicesManagementApi.getDeviceInfo(deviceId);
      deviceInfo = DeviceInfoModel.fromJson(response);
      nameController.text = deviceInfo.name;

      emit(UpdateSettingState(
        deviceName: nameController.text,
        deviceInfo: deviceInfo,
      ));
    } catch (e) {
      emit(ErrorState(message: e.toString()));
    }
  }

  bool editName = false;
  final FocusNode focusNode = FocusNode();

  void _changeName(ChangeNameEvent event, Emitter<DeviceSettingsState> emit) {
    emit(SettingLoadingState());
    editName = event.value!;
    if (editName) {
      Future.delayed(const Duration(milliseconds: 500), () {
        focusNode.requestFocus();
      });
    } else {
      add(const SaveNameEvent());
      focusNode.unfocus();
    }
    emit(UpdateSettingState(deviceName: deviceName, deviceInfo: deviceInfo));
  }

  void deleteDevice(
      DeleteDeviceEvent event, Emitter<DeviceSettingsState> emit) async {
    try {
      emit(SettingLoadingState());
      var response =
          await DevicesManagementApi.resetDevise(devicesUuid: deviceId);
      CustomSnackBar.displaySnackBar('Reset Successfully');
      emit(UpdateSettingState(
        deviceName: nameController.text,
        deviceInfo: deviceInfo,
      ));
    } catch (e) {
      emit(ErrorState(message: e.toString()));
      return;
    }
  }
}
